]> git.puffer.fish Git - mirror/frr.git/commitdiff
*: Cleanup some documentation from quagga->frr 10036/head
authorDonald Sharp <sharpd@nvidia.com>
Thu, 11 Nov 2021 19:40:17 +0000 (14:40 -0500)
committerDonald Sharp <sharpd@nvidia.com>
Thu, 11 Nov 2021 19:41:27 +0000 (14:41 -0500)
Signed-off-by: Donald Sharp <sharpd@nvidia.com>
doc/user/babeld.rst
gdb/lib.txt
lib/if.h
ospfd/ospf_packet.c
ospfd/ospf_snmp.c
ospfd/ospfd.c
zebra/kernel_socket.c
zebra/main.c

index c8015bb7e553820fd58ab23e6f608f8e76cb9845..2d9fef13c345736bbbb9eb31e53d1c38a5fc484e 100644 (file)
@@ -268,6 +268,6 @@ Babel sample configuration file
    ! babel hello-interval 12000
    ! babel update-interval 36000
 
-   ! log file /var/log/quagga/babeld.log
+   ! log file /var/log/frr/babeld.log
    log stdout
 
index 60a004e1e1cb035d339ecb0167bed8e807f82376..913b455ed1d6f9a45c68a24c1531598f2f498a32 100644 (file)
@@ -1,6 +1,6 @@
 # GDB macros for use with Quagga.
 #
-# Macros in this file are not daemon specific. E.g., OS or Quagga library
+# Macros in this file are not daemon specific. E.g., OS or FRR library
 # APIs.
 #
 # The macro file can be loaded with 'source <filename>'. They can then be
@@ -9,7 +9,7 @@
 #
 # E.g.:
 # 
-# (gdb) source ~paul/code/quagga/gdb/lib.txt
+# (gdb) source ~paul/code/frr/gdb/lib.txt
 # (gdb) break bgp_packet.c:613
 # Breakpoint 3 at 0x7fa883033a32: file bgp_packet.c, line 613.
 # (gdb) cont
index 506c14ff598b43381e20df79282584718e2fb996..1012bf5557ea22eb56b3dc40a2b988516feeaa12 100644 (file)
--- a/lib/if.h
+++ b/lib/if.h
@@ -399,16 +399,12 @@ struct connected {
        /*
           The ZEBRA_IFC_REAL flag should be set if and only if this address
           exists in the kernel and is actually usable. (A case where it exists
-          but
-          is not yet usable would be IPv6 with DAD)
+          but is not yet usable would be IPv6 with DAD)
           The ZEBRA_IFC_CONFIGURED flag should be set if and only if this
-          address
-          was configured by the user from inside quagga.
+          address was configured by the user from inside frr.
           The ZEBRA_IFC_QUEUED flag should be set if and only if the address
-          exists
-          in the kernel. It may and should be set although the address might
-          not be
-          usable yet. (compare with ZEBRA_IFC_REAL)
+          exists in the kernel. It may and should be set although the
+          address might not be usable yet. (compare with ZEBRA_IFC_REAL)
           The ZEBRA_IFC_DOWN flag is used to record that an address is
           present, but down/unavailable.
         */
index 1ebb14f2a0ebd83faedb3bda2f7547dbbd529e5b..ede0ad39e6e15dc184a13b1ecf8c7090cd068cf8 100644 (file)
@@ -398,7 +398,7 @@ static int ospf_make_md5_digest(struct ospf_interface *oi,
        /* We do this here so when we dup a packet, we don't have to
           waste CPU rewriting other headers.
 
-          Note that quagga_time /deliberately/ is not used here */
+          Note that frr_time /deliberately/ is not used here */
        t = (time(NULL) & 0xFFFFFFFF);
        if (t > oi->crypt_seqnum)
                oi->crypt_seqnum = t;
index a1ea4e45d7fb6d572222dc4c47210d7ddb207feb..7ec3db7894634237c4120947f036c21b9157ffaa 100644 (file)
@@ -2090,7 +2090,7 @@ static struct ospf_neighbor *ospfNbrLookup(struct variable *v, oid *name,
        return NULL;
 }
 
/* map internal quagga neighbor states to official MIB values:
 
 ospfNbrState OBJECT-TYPE
        SYNTAX   INTEGER    {
index 1e1057dc39e1acb324edcc60aa69b072404f847e..dd0a49c9bc52acc1b4ec6a1d4aff5af620412c4a 100644 (file)
@@ -192,7 +192,7 @@ void ospf_process_refresh_data(struct ospf *ospf, bool reset)
                   hit
                   asserts in ospf_refresher_unregister_lsa(). This step is
                   needed
-                  because the current quagga code does look-up for
+                  because the current frr code does look-up for
                   self-originated LSAs
                   based on the self router-id alone but expects OSPF_LSA_SELF
                   to be
index 2db3e6e9047a67192c973236a0aabfb11eeaadcd..5ff66f7c63371a8aa9c73d0999e633cef44e610c 100644 (file)
@@ -61,7 +61,7 @@ extern struct zebra_privs_t zserv_privs;
  * Alignment of zero-sized sockaddrs is nonsensical, but historically
  * BSD defines RT_ROUNDUP(0) to be the alignment interval (rather than
  * 0).  We follow this practice without questioning it, but it is a
* bug if quagga calls ROUNDUP with 0.
  */
 #ifdef __APPLE__
 #define ROUNDUP_TYPE   int
index 5694a442a240511a9fdd8d3f42115bc7cd83aec3..e4363bd89947f411c886fabf2f731e586894c204 100644 (file)
@@ -71,7 +71,7 @@ struct thread_master *master;
 /* Route retain mode flag. */
 int retain_mode = 0;
 
/* Allow non-quagga entities to delete quagga routes */
 int allow_delete = 0;
 
 int graceful_restart;
@@ -2090,7 +2090,7 @@ static struct ospf_neighbor *ospfNbrLookup(struct variable *v, oid *name,
 }
 
-/* map internal quagga neighbor states to official MIB values:
+/* map internal frr neighbor states to official MIB values:
 
 ospfNbrState OBJECT-TYPE
@@ -61,7 +61,7 @@ extern struct zebra_privs_t zserv_privs;
  * BSD defines RT_ROUNDUP(0) to be the alignment interval (rather than
  * 0).  We follow this practice without questioning it, but it is a
- * bug if quagga calls ROUNDUP with 0.
+ * bug if frr calls ROUNDUP with 0.
  */
 #ifdef __APPLE__
@@ -71,7 +71,7 @@ struct thread_master *master;
 int retain_mode = 0;
 
-/* Allow non-quagga entities to delete quagga routes */
+/* Allow non-frr entities to delete frr routes */
 int allow_delete = 0;
 